@@ -62,6 +62,9 @@ import System.FilePath ((<.>), (</>), makeRelative, splitFileName, takeDirectory
 import System.IO (hPutStrLn, stderr)
 import Text.Parsec.Rfc2822 (NameAddr(..))
 import Distribution.Pretty (Pretty(pretty))
+#if MIN_VERSION_Cabal(3,14,0)
+import Distribution.Utils.Path (interpretSymbolicPath)
+#endif
 
 -- | @debianize customize@ initializes the CabalT state from the
 -- environment and the cabal package description in (and possibly the
@@ -89,8 +92,7 @@ finalizeDebianization goodies =
     do date <- liftIO getCurrentLocalRFC822Time
        currentUser <- liftIO getCurrentDebianUser
        debhelperCompat <- liftIO getDebhelperCompatLevel
-       setupExists <- or <$> mapM (liftIO . doesFileExist) ["Setup.hs", "Setup.lhs"]
-       finalizeDebianization' goodies date currentUser debhelperCompat setupExists
+       finalizeDebianization' goodies date currentUser debhelperCompat
        vb <- use (A.debInfo . D.flags . verbosity)
        when (vb >= 3) (get >>= \ x -> liftIO (putStrLn ("\nFinalized Cabal Info: " ++ show x ++ "\n")))
        either (\e -> liftIO $ hPutStrLn stderr ("WARNING: " ++ e)) (\_ -> return ()) =<< use (A.debInfo . D.control . S.maintainer)
@@ -109,9 +111,8 @@ finalizeDebianization' ::
     -> String
     -> Maybe NameAddr
     -> Maybe Int
-    -> Bool
     -> CabalT m ()
-finalizeDebianization' goodies date currentUser debhelperCompat setupExists =
+finalizeDebianization' goodies date currentUser debhelperCompat =
     do -- In reality, hcs must be a singleton or many things won't work.  But some day...
        hc <- use (A.debInfo . D.flags . compilerFlavor)
        pkgDesc <- use A.packageDescription
@@ -122,8 +123,6 @@ finalizeDebianization' goodies date currentUser debhelperCompat setupExists =
          (True, D.TestsRun) -> (A.debInfo . D.rulesSettings) %= (++ ["DEB_ENABLE_TESTS = yes"])
          (True, D.TestsBuild) -> (A.debInfo . D.rulesSettings) %= (++ ["DEB_ENABLE_TESTS = yes", "DEB_BUILD_OPTIONS += nocheck"])
          _ -> return ()
-       (A.debInfo . D.rulesSettings) %=
-          (++ ["DEB_SETUP_BIN_NAME = " <> if setupExists then "debian/hlibrary.setup" else "cabal"])
  
        finalizeSourceName B.HaskellSource
        checkOfficialSettings hc
@@ -463,7 +462,7 @@ officialSettings = do
 
         let packagesURI = "https://salsa.debian.org/haskell-team/DHG_packages/tree/master/p/" <> pack src
         zoom D.control $ do
-           S.standardsVersion .?= Just (parseStandardsVersion "4.7.0")
+           S.standardsVersion .?= Just (parseStandardsVersion "4.7.2")
            S.homepage .?= Just ("https://hackage.haskell.org/package/" <> pack (unPackageName cabal))
            S.vcsFields %= Set.union (Set.fromList
               [ S.VCSBrowser packagesURI
@@ -582,7 +581,12 @@ makeUtilsPackage pkgDesc hc =
            installedExec = Set.unions (Map.elems installedExecMap)
 
        prefixPath <- dataTop
-       let dataFilePaths = Set.fromList (zip (List.map (prefixPath </>) (Cabal.dataFiles pkgDesc)) (Cabal.dataFiles pkgDesc)) :: Set (FilePath, FilePath)
+#if MIN_VERSION_Cabal(3,14,0)
+       let dFpD = List.map (interpretSymbolicPath Nothing) (Cabal.dataFiles pkgDesc)
+#else
+       let dFpD = Cabal.dataFiles pkgDesc
+#endif
+           dataFilePaths = Set.fromList (zip (List.map (prefixPath </>) dFpD) dFpD) :: Set (FilePath, FilePath)
            execFilePaths :: Set FilePath
            execFilePaths = Set.map (unUnqualComponentName . Cabal.exeName) (Set.filter (Cabal.buildable . Cabal.buildInfo) (Set.fromList (Cabal.executables pkgDesc))) :: Set FilePath
        let availableData = Set.union installedData dataFilePaths
