@@ -1,4 +1,5 @@
 -- | Read an existing Debianization from a directory file.
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE DeriveDataTypeable, FlexibleInstances, ScopedTypeVariables, TypeSynonymInstances #-}
 {-# OPTIONS_GHC -Wall -fno-warn-orphans #-}
 module Debian.Debianize.InputDebian
@@ -38,6 +39,9 @@ import Debian.Relation (BinPkgName(..), parseRelations, Relations, SrcPkgName(..
 --import Debug.Trace (trace)
 import Distribution.Package (PackageIdentifier(..), unPackageName)
 import qualified Distribution.PackageDescription as Cabal (dataDir, PackageDescription(package))
+#if MIN_VERSION_Cabal(3,14,0)
+import Distribution.Utils.Path (interpretSymbolicPath)
+#endif
 import Prelude hiding (break, lines, log, null, readFile, sum, words)
 import System.Directory (doesFileExist)
 import System.FilePath ((</>), dropExtension, takeExtension)
@@ -298,6 +302,10 @@ dataDest = do
 dataTop :: Monad m => CabalT m FilePath
 dataTop = do
   d <- use packageDescription
+#if MIN_VERSION_Cabal(3,14,0)
+  return $ case interpretSymbolicPath Nothing (Cabal.dataDir d) of
+#else
   return $ case Cabal.dataDir d of
+#endif
              "" -> "."
              x -> x
